# The Dozer Simulation Project

Welcome to the dozer-project. Dozer stands for Drive OptimiZER. It containts inverse models of gearboxes, electric motors, etc. in the It can simulate and optimize electrical and mechanical systems.


## Installation 
```commandline
py -m pip install dozersim
```

## Use


For in-depth instructions on installation and building the documentation, see  [Dozer Documentation](https://cormeijneke.gitlab.io/dozer/#) for detailed information.

